spoon.messaging.messagingcore

Package spoon :: Package messaging :: Module messagingcore |
[hide private]
[frames] | no frames]

# Module messagingcore

source code

Classes | [hide private]
`` | Messaging This is the main messaging class that implements the basic functionality for Spoon.
`` | SingletonMessaging For convinience this is a singleton version of the Messaging system.

Functions | [hide private]
`` | send(dst, messageStr, obj) Shortcut for calling send on the SingletonMessaging class.

Function Details | [hide private]

### send(dst, messageStr, obj) | source code
Shortcut for calling send on the SingletonMessaging class. Parameters: `dst` - Destination node id `messageStr` - A string describing the message type. `obj` - Some object attached the net message.